==> chrome-devtools-kotlin-1.0.0-sources.jar: org/hildan/chrome/devtools/domains/runtime/events/RuntimeEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.runtime.events

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import kotlinx.serialization.json.JsonElement
import org.hildan.chrome.devtools.domains.runtime.ExceptionDetails
import org.hildan.chrome.devtools.domains.runtime.ExecutionContextDescription
import org.hildan.chrome.devtools.domains.runtime.ExecutionContextId
import org.hildan.chrome.devtools.domains.runtime.RemoteObject
import org.hildan.chrome.devtools.domains.runtime.StackTrace
import org.hildan.chrome.devtools.domains.runtime.Timestamp
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

@Serializable
public sealed class RuntimeEvent {
  /**
   * Notification is issued every time when binding is called.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-bindingCalled)
   */
  @ExperimentalChromeApi
  @Serializable
  public data class BindingCalledEvent(
    public val name: String,
    public val payload: String,
    /**
     * Identifier of the context where the call was made.
     */
    public val executionContextId: ExecutionContextId
  ) : RuntimeEvent()

  /**
   * Issued when console API was called.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-consoleAPICalled)
   */
  @Serializable
  public data class ConsoleAPICalledEvent(
    /**
     * Type of the call.
     */
    public val type: String,
    /**
     * Call arguments.
     */
    public val args: List<RemoteObject>,
    /**
     * Identifier of the context where the call was made.
     */
    public val executionContextId: ExecutionContextId,
    /**
     * Call timestamp.
     */
    public val timestamp: Timestamp,
    /**
     * Stack trace captured when the call was made. The async stack chain is automatically reported
     * for
     * the following call types: `assert`, `error`, `trace`, `warning`. For other types the async
     * call
     * chain can be retrieved using `Debugger.getStackTrace` and `stackTrace.parentId` field.
     */
    public val stackTrace: StackTrace? = null,
    /**
     * Console context descriptor for calls on non-default console context (not console.*):
     * 'anonymous#unique-logger-id' for call on unnamed context, 'name#unique-logger-id' for call
     * on named context.
     */
    @ExperimentalChromeApi
    public val context: String? = null
  ) : RuntimeEvent()

  /**
   * Issued when unhandled exception was revoked.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-exceptionRevoked)
   */
  @Serializable
  public data class ExceptionRevokedEvent(
    /**
     * Reason describing why exception was revoked.
     */
    public val reason: String,
    /**
     * The id of revoked exception, as reported in `exceptionThrown`.
     */
    public val exceptionId: Int
  ) : RuntimeEvent()

  /**
   * Issued when exception was thrown and unhandled.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-exceptionThrown)
   */
  @Serializable
  public data class ExceptionThrownEvent(
    /**
     * Timestamp of the exception.
     */
    public val timestamp: Timestamp,
    public val exceptionDetails: ExceptionDetails
  ) : RuntimeEvent()

  /**
   * Issued when new execution context is created.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextCreated)
   */
  @Serializable
  public data class ExecutionContextCreatedEvent(
    /**
     * A newly created execution context.
     */
    public val context: ExecutionContextDescription
  ) : RuntimeEvent()

  /**
   * Issued when execution context is destroyed.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextDestroyed)
   */
  @Serializable
  public data class ExecutionContextDestroyedEvent(
    /**
     * Id of the destroyed context
     */
    public val executionContextId: ExecutionContextId
  ) : RuntimeEvent()

  /**
   * Issued when all executionContexts were cleared in browser
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextsCleared)
   */
  @Serializable
  public object ExecutionContextsClearedEvent : RuntimeEvent()

  /**
   * Issued when object should be inspected (for example, as a result of inspect() command line API
   * call).
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-inspectRequested)
   */
  @Serializable
  public data class InspectRequestedEvent(
    public val `object`: RemoteObject,
    public val hints: JsonElement
  ) : RuntimeEvent()
}

==> chrome-devtools-kotlin-4.2.0-sources.jar: org/hildan/chrome/devtools/domains/runtime/events/RuntimeEvents.kt <==
@file:Suppress("RedundantVisibilityModifier", "DEPRECATION", "EXPERIMENTAL_API_USAGE")

package org.hildan.chrome.devtools.domains.runtime.events

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlinx.serialization.Serializable
import kotlinx.serialization.json.JsonObject
import org.hildan.chrome.devtools.domains.runtime.ConsoleAPICalledType
import org.hildan.chrome.devtools.domains.runtime.ExceptionDetails
import org.hildan.chrome.devtools.domains.runtime.ExecutionContextDescription
import org.hildan.chrome.devtools.domains.runtime.ExecutionContextId
import org.hildan.chrome.devtools.domains.runtime.RemoteObject
import org.hildan.chrome.devtools.domains.runtime.StackTrace
import org.hildan.chrome.devtools.domains.runtime.Timestamp
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

@Serializable
public sealed class RuntimeEvent {
  /**
   * Notification is issued every time when binding is called.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-bindingCalled)
   */
  @ExperimentalChromeApi
  @Serializable
  public data class BindingCalled(
    public val name: String,
    public val payload: String,
    /**
     * Identifier of the context where the call was made.
     */
    public val executionContextId: ExecutionContextId,
  ) : RuntimeEvent()

  /**
   * Issued when console API was called.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-consoleAPICalled)
   */
  @Serializable
  public data class ConsoleAPICalled(
    /**
     * Type of the call.
     */
    public val type: ConsoleAPICalledType,
    /**
     * Call arguments.
     */
    public val args: List<RemoteObject>,
    /**
     * Identifier of the context where the call was made.
     */
    public val executionContextId: ExecutionContextId,
    /**
     * Call timestamp.
     */
    public val timestamp: Timestamp,
    /**
     * Stack trace captured when the call was made. The async stack chain is automatically reported
     * for
     * the following call types: `assert`, `error`, `trace`, `warning`. For other types the async
     * call
     * chain can be retrieved using `Debugger.getStackTrace` and `stackTrace.parentId` field.
     */
    public val stackTrace: StackTrace? = null,
    /**
     * Console context descriptor for calls on non-default console context (not console.*):
     * 'anonymous#unique-logger-id' for call on unnamed context, 'name#unique-logger-id' for call
     * on named context.
     */
    @ExperimentalChromeApi
    public val context: String? = null,
  ) : RuntimeEvent()

  /**
   * Issued when unhandled exception was revoked.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-exceptionRevoked)
   */
  @Serializable
  public data class ExceptionRevoked(
    /**
     * Reason describing why exception was revoked.
     */
    public val reason: String,
    /**
     * The id of revoked exception, as reported in `exceptionThrown`.
     */
    public val exceptionId: Int,
  ) : RuntimeEvent()

  /**
   * Issued when exception was thrown and unhandled.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-exceptionThrown)
   */
  @Serializable
  public data class ExceptionThrown(
    /**
     * Timestamp of the exception.
     */
    public val timestamp: Timestamp,
    public val exceptionDetails: ExceptionDetails,
  ) : RuntimeEvent()

  /**
   * Issued when new execution context is created.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextCreated)
   */
  @Serializable
  public data class ExecutionContextCreated(
    /**
     * A newly created execution context.
     */
    public val context: ExecutionContextDescription,
  ) : RuntimeEvent()

  /**
   * Issued when execution context is destroyed.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextDestroyed)
   */
  @Serializable
  public data class ExecutionContextDestroyed(
    /**
     * Id of the destroyed context
     */
    public val executionContextId: ExecutionContextId,
  ) : RuntimeEvent()

  /**
   * Issued when all executionContexts were cleared in browser
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-executionContextsCleared)
   */
  @Serializable
  public object ExecutionContextsCleared : RuntimeEvent()

  /**
   * Issued when object should be inspected (for example, as a result of inspect() command line API
   * call).
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Runtime/#event-inspectRequested)
   */
  @Serializable
  public data class InspectRequested(
    public val `object`: RemoteObject,
    public val hints: JsonObject,
    /**
     * Identifier of the context where the call was made.
     */
    @ExperimentalChromeApi
    public val executionContextId: ExecutionContextId? = null,
  ) : RuntimeEvent()
}
